wallaroo.wallaroo_ml_ops_api_client.models.assays_filter_response_200_item_summarizer_type_0_metric API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.assays_filter_response_200_item_summarizer_type_0_metric

View Source

     1from enum import Enum
     2
     3
     4class AssaysFilterResponse200ItemSummarizerType0Metric(str, Enum):
     5    MAXDIFF = "MaxDiff"
     6    SUMDIFF = "SumDiff"
     7    PSI = "PSI"
     8
     9    def __str__(self) -> str:
    10        return str(self.value)

class AssaysFilterResponse200ItemSummarizerType0Metric(builtins.str, enum.Enum): View Source

     5class AssaysFilterResponse200ItemSummarizerType0Metric(str, Enum):
     6    MAXDIFF = "MaxDiff"
     7    SUMDIFF = "SumDiff"
     8    PSI = "PSI"
     9
    10    def __str__(self) -> str:
    11        return str(self.value)

An enumeration.

MAXDIFF = <AssaysFilterResponse200ItemSummarizerType0Metric.MAXDIFF: 'MaxDiff'>
SUMDIFF = <AssaysFilterResponse200ItemSummarizerType0Metric.SUMDIFF: 'SumDiff'>
PSI = <AssaysFilterResponse200ItemSummarizerType0Metric.PSI: 'PSI'>

##### Inherited Members

enum.Enum
  name
  value
builtins.str
  encode
  replace
  split
  rsplit
  join
  capitalize
  casefold
  title
  center
  count
  expandtabs
  find
  partition
  index
  ljust
  lower
  lstrip
  rfind
  rindex
  rjust
  rstrip
  rpartition
  splitlines
  strip
  swapcase
  translate
  upper
  startswith
  endswith
  removeprefix
  removesuffix
  isascii
  islower
  isupper
  istitle
  isspace
  isdecimal
  isdigit
  isnumeric
  isalpha
  isalnum
  isidentifier
  isprintable
  zfill
  format
  format_map
  maketrans